==> keycloak-model-map-18.0.2-sources.jar: org/keycloak/models/map/loginFailure/MapUserLoginFailureEntityDelegate.java <==
package org.keycloak.models.map.loginFailure;
public class MapUserLoginFailureEntityDelegate implements org.keycloak.models.map.loginFailure.MapUserLoginFailureEntity {
    private final org.keycloak.models.map.common.delegate.DelegateProvider<org.keycloak.models.map.loginFailure.MapUserLoginFailureEntity> delegateProvider;
    public MapUserLoginFailureEntityDelegate(org.keycloak.models.map.common.delegate.DelegateProvider<org.keycloak.models.map.loginFailure.MapUserLoginFailureEntity> delegateProvider) {
        this.delegateProvider = delegateProvider;
    }
    @Override public boolean isUpdated() {
        return delegateProvider.isUpdated();
    }
    @Override public String getId() {
        return delegateProvider.getDelegate(true, org.keycloak.models.map.loginFailure.MapUserLoginFailureEntityFields.ID).getId();
    }
    @Override public void setId(String id) {
        delegateProvider.getDelegate(false, org.keycloak.models.map.loginFailure.MapUserLoginFailureEntityFields.ID, id).setId(id);
    }
    @Override public String getRealmId() {
        return delegateProvider.getDelegate(true, org.keycloak.models.map.loginFailure.MapUserLoginFailureEntityFields.REALM_ID).getRealmId();
    }
    @Override public void setRealmId(String realmId) {
        delegateProvider.getDelegate(false, org.keycloak.models.map.loginFailure.MapUserLoginFailureEntityFields.REALM_ID, realmId).setRealmId(realmId);
    }
    @Override public String getUserId() {
        return delegateProvider.getDelegate(true, org.keycloak.models.map.loginFailure.MapUserLoginFailureEntityFields.USER_ID).getUserId();
    }
    @Override public void setUserId(String userId) {
        delegateProvider.getDelegate(false, org.keycloak.models.map.loginFailure.MapUserLoginFailureEntityFields.USER_ID, userId).setUserId(userId);
    }
    @Override public Long getFailedLoginNotBefore() {
        return delegateProvider.getDelegate(true, org.keycloak.models.map.loginFailure.MapUserLoginFailureEntityFields.FAILED_LOGIN_NOT_BEFORE).getFailedLoginNotBefore();
    }
    @Override public void setFailedLoginNotBefore(Long failedLoginNotBefore) {
        delegateProvider.getDelegate(false, org.keycloak.models.map.loginFailure.MapUserLoginFailureEntityFields.FAILED_LOGIN_NOT_BEFORE, failedLoginNotBefore).setFailedLoginNotBefore(failedLoginNotBefore);
    }
    @Override public Integer getNumFailures() {
        return delegateProvider.getDelegate(true, org.keycloak.models.map.loginFailure.MapUserLoginFailureEntityFields.NUM_FAILURES).getNumFailures();
    }
    @Override public void setNumFailures(Integer numFailures) {
        delegateProvider.getDelegate(false, org.keycloak.models.map.loginFailure.MapUserLoginFailureEntityFields.NUM_FAILURES, numFailures).setNumFailures(numFailures);
    }
    @Override public Long getLastFailure() {
        return delegateProvider.getDelegate(true, org.keycloak.models.map.loginFailure.MapUserLoginFailureEntityFields.LAST_FAILURE).getLastFailure();
    }
    @Override public void setLastFailure(Long lastFailure) {
        delegateProvider.getDelegate(false, org.keycloak.models.map.loginFailure.MapUserLoginFailureEntityFields.LAST_FAILURE, lastFailure).setLastFailure(lastFailure);
    }
    @Override public String getLastIPFailure() {
        return delegateProvider.getDelegate(true, org.keycloak.models.map.loginFailure.MapUserLoginFailureEntityFields.LAST_IPFAILURE).getLastIPFailure();
    }
    @Override public void setLastIPFailure(String lastIPFailure) {
        delegateProvider.getDelegate(false, org.keycloak.models.map.loginFailure.MapUserLoginFailureEntityFields.LAST_IPFAILURE, lastIPFailure).setLastIPFailure(lastIPFailure);
    }
    @Override public void clearFailures() {
        delegateProvider.getDelegate(false, null).clearFailures();
    }
}

==> keycloak-model-map-21.0.0-sources.jar: org/keycloak/models/map/loginFailure/MapUserLoginFailureEntityDelegate.java <==
package org.keycloak.models.map.loginFailure;
@javax.annotation.processing.Generated("org.keycloak.models.map.processor.GenerateEntityImplementationsProcessor")
public class MapUserLoginFailureEntityDelegate implements org.keycloak.models.map.loginFailure.MapUserLoginFailureEntity, org.keycloak.models.map.common.delegate.HasDelegateProvider<org.keycloak.models.map.loginFailure.MapUserLoginFailureEntity> {
    private final org.keycloak.models.map.common.delegate.DelegateProvider<org.keycloak.models.map.loginFailure.MapUserLoginFailureEntity> delegateProvider;
    public MapUserLoginFailureEntityDelegate(org.keycloak.models.map.common.delegate.DelegateProvider<org.keycloak.models.map.loginFailure.MapUserLoginFailureEntity> delegateProvider) {
        this.delegateProvider = delegateProvider;
    }
    public org.keycloak.models.map.common.delegate.DelegateProvider<org.keycloak.models.map.loginFailure.MapUserLoginFailureEntity> getDelegateProvider() {
        return this.delegateProvider;
    }
    @Override public boolean isUpdated() {
        return delegateProvider.isUpdated();
    }
    @Override public String getId() {
        return delegateProvider.getDelegate(true, org.keycloak.models.map.loginFailure.MapUserLoginFailureEntityFields.ID).getId();
    }
    @Override public void setId(String id) {
        delegateProvider.getDelegate(false, org.keycloak.models.map.loginFailure.MapUserLoginFailureEntityFields.ID, id).setId(id);
    }
    @Override public String getRealmId() {
        return delegateProvider.getDelegate(true, org.keycloak.models.map.loginFailure.MapUserLoginFailureEntityFields.REALM_ID).getRealmId();
    }
    @Override public void setRealmId(String realmId) {
        delegateProvider.getDelegate(false, org.keycloak.models.map.loginFailure.MapUserLoginFailureEntityFields.REALM_ID, realmId).setRealmId(realmId);
    }
    @Override public String getUserId() {
        return delegateProvider.getDelegate(true, org.keycloak.models.map.loginFailure.MapUserLoginFailureEntityFields.USER_ID).getUserId();
    }
    @Override public void setUserId(String userId) {
        delegateProvider.getDelegate(false, org.keycloak.models.map.loginFailure.MapUserLoginFailureEntityFields.USER_ID, userId).setUserId(userId);
    }
    @Override public Long getFailedLoginNotBefore() {
        return delegateProvider.getDelegate(true, org.keycloak.models.map.loginFailure.MapUserLoginFailureEntityFields.FAILED_LOGIN_NOT_BEFORE).getFailedLoginNotBefore();
    }
    @Override public void setFailedLoginNotBefore(Long failedLoginNotBefore) {
        delegateProvider.getDelegate(false, org.keycloak.models.map.loginFailure.MapUserLoginFailureEntityFields.FAILED_LOGIN_NOT_BEFORE, failedLoginNotBefore).setFailedLoginNotBefore(failedLoginNotBefore);
    }
    @Override public Integer getNumFailures() {
        return delegateProvider.getDelegate(true, org.keycloak.models.map.loginFailure.MapUserLoginFailureEntityFields.NUM_FAILURES).getNumFailures();
    }
    @Override public void setNumFailures(Integer numFailures) {
        delegateProvider.getDelegate(false, org.keycloak.models.map.loginFailure.MapUserLoginFailureEntityFields.NUM_FAILURES, numFailures).setNumFailures(numFailures);
    }
    @Override public Long getLastFailure() {
        return delegateProvider.getDelegate(true, org.keycloak.models.map.loginFailure.MapUserLoginFailureEntityFields.LAST_FAILURE).getLastFailure();
    }
    @Override public void setLastFailure(Long lastFailure) {
        delegateProvider.getDelegate(false, org.keycloak.models.map.loginFailure.MapUserLoginFailureEntityFields.LAST_FAILURE, lastFailure).setLastFailure(lastFailure);
    }
    @Override public String getLastIPFailure() {
        return delegateProvider.getDelegate(true, org.keycloak.models.map.loginFailure.MapUserLoginFailureEntityFields.LAST_IPFAILURE).getLastIPFailure();
    }
    @Override public void setLastIPFailure(String lastIPFailure) {
        delegateProvider.getDelegate(false, org.keycloak.models.map.loginFailure.MapUserLoginFailureEntityFields.LAST_IPFAILURE, lastIPFailure).setLastIPFailure(lastIPFailure);
    }
    @Override public void clearFailures() {
        delegateProvider.getDelegate(false, null).clearFailures();
    }
}
